#[non_exhaustive]pub enum Sink {
Null,
Vector(Vec<u8>),
File(File),
TcpStream(TcpStream),
Other(Box<dyn AnySink + Send + UnwindSafe>),
}Expand description
A type-abstract data sink
Rationale
The idea behind this type is to provide some dynamic polymorphism, but with some “fast-paths” for common types to avoid the overhead of boxing and vtable-lookup (while the latter is probable negligible, the former may be significant overhead if all you want is to write to some preallocated memory).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Null
A writer which will move data into the void
Vector(Vec<u8>)
A vector sink
File(File)
A file
TcpStream(TcpStream)
A TCP stream
Other(Box<dyn AnySink + Send + UnwindSafe>)
A catch-all/opaque variant for all types that cannot be covered by the enum’s specific variants
Implementations
sourceimpl Sink
impl Sink
sourcepub fn from_other<T>(typed: T) -> Self
pub fn from_other<T>(typed: T) -> Self
Creates a new catch-all/opaque variant from a typed object by moving it to the heap