Request

Struct Request 

pub struct Request<'a, const HEADER_SIZE_MAX: usize = 4096> {
    pub header: Data,
    pub method: Data,
    pub target: Data,
    pub version: Data,
    pub fields: Vec<(Data, Data)>,
    pub stream: &'a mut Source,
}
A HTTP request

Fields

header: Data

The raw header bytes

method: Data

The method part within the request line

target: Data

The target part within the request line

version: Data

The version part within the request line

fields: Vec<(Data, Data)>

The key/value fields within the header

stream: &'a mut Source

The connection stream

Implementations

Source

impl<'a, const HEADER_SIZE_MAX: usize> Request<'a, HEADER_SIZE_MAX>

pub fn from_stream(stream: &'a mut Source) -> Result<Option<Self>, Error>

Reads a HTTP request from a readable stream

Source

impl<'a, const HEADER_SIZE_MAX: usize> Request<'a, HEADER_SIZE_MAX>

pub fn target_path(&self) -> Option<&Path>

Gets the request target as path

Important

On non-unix platforms, this function uses a str as intermediate representation, so the path must be valid UTF-8. If this might be a problem, you should use the raw target field directly.

pub fn field<N>(&self, name: N) -> Option<&Data>
where N: AsRef<[u8]>,

Gets the field with the given name (performs an ASCII-case-insensitve comparison)

pub fn content_length(&self) -> Result<Option<u64>, Error>

The request content length field if any

pub fn read_body_data( &mut self, content_length_max: u64, ) -> Result<Option<Data>, Error>

Reads the request body into memory if a content-length header is set and transfer-encoding is not chunked; returns None otherwise